# -*- coding: utf-8 -*-
"""
DO NOT EDIT! This file is auto-generated

Classes for Skyline Message Bus usage.
"""
from __future__ import absolute_import

# Import python libs
import json
import sys
from datetime import datetime  # pylint: disable=unused-import

# Import local libs
# pylint: disable=import-error
from niskyline.messagebus.broadcast_message import BroadcastMessage  # pylint: disable=unused-import
from niskyline.messagebus.datetime import from_datetime, to_datetime  # pylint: disable=unused-import
from niskyline.messagebus.message_header import (  # pylint: disable=unused-import
    MessageHeader, JSON_MESSAGE_CONTENT_TYPE, BINARY_MESSAGE_CONTENT_TYPE)
from niskyline.messagebus.message_base import MessageBase
from niskyline.messagebus.request_message import RequestMessage  # pylint: disable=unused-import
from niskyline.messagebus.response_message import ResponseMessage  # pylint: disable=unused-import
from niskyline.messagebus.routed_message import RoutedMessage  # pylint: disable=unused-import
# pylint: enable=import-error

if sys.version_info[0] >= 3:
    long = int  # pylint: disable=redefined-builtin,invalid-name


# pylint: disable=line-too-long,too-many-lines,too-many-instance-attributes


#
# AssetPerformanceManagementMessageObjects namespace
#


class TemperatureData(object):
    """
    TemperatureData custom data type.
    """
    def __init__(self,
                 name_,
                 reading_):
        """
        :param name_: name
        :type name_: str
        :param reading_: reading
        :type reading_: float
        """
        self.name = name_
        self.reading = reading_

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`TemperatureData` using a dictionary.

        :param body_dict: A dictionary representing the body.
        :type body_dict: dict
        :return: A new instance of :class:`TemperatureData`.
        :rtype: TemperatureData
        """
        name_ = body_dict.get('name')
        reading_ = body_dict.get('reading')
        return cls(
            name_=name_,
            reading_=reading_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`TemperatureData` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`TemperatureData`.
        :rtype: TemperatureData
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`TemperatureData` using a body
        of type :class:`bytes` or :class:`bytesarray`.

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`TemperatureData`.
        :rtype: TemperatureData
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        name_ = self.name
        reading_ = self.reading
        return {
            'name': name_,
            'reading': reading_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')


class ExternalCalibrationData(object):
    """
    ExternalCalibrationData custom data type.
    """
    def __init__(self,
                 date_,
                 next_recommended_date_,
                 recommended_interval_,
                 is_limited_,
                 supports_limited_,
                 supports_write_,
                 temperature_info_,
                 checksum_,
                 comments_):
        """
        :param date_: date
        :type date_: str
        :param next_recommended_date_: next_recommended_date
        :type next_recommended_date_: str
        :param recommended_interval_: recommended_interval
        :type recommended_interval_: int
        :param is_limited_: is_limited
        :type is_limited_: bool
        :param supports_limited_: supports_limited
        :type supports_limited_: bool
        :param supports_write_: supports_write
        :type supports_write_: bool
        :param temperature_info_: temperature_info
        :type temperature_info_: list(TemperatureData)
        :param checksum_: checksum
        :type checksum_: str
        :param comments_: comments
        :type comments_: str
        """
        self.date = date_
        self.next_recommended_date = next_recommended_date_
        self.recommended_interval = recommended_interval_
        self.is_limited = is_limited_
        self.supports_limited = supports_limited_
        self.supports_write = supports_write_
        self.temperature_info = temperature_info_
        self.checksum = checksum_
        self.comments = comments_

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`ExternalCalibrationData` using a dictionary.

        :param body_dict: A dictionary representing the body.
        :type body_dict: dict
        :return: A new instance of :class:`ExternalCalibrationData`.
        :rtype: ExternalCalibrationData
        """
        date_ = body_dict.get('date')
        next_recommended_date_ = body_dict.get('nextRecommendedDate')
        recommended_interval_ = body_dict.get('recommendedInterval')
        is_limited_ = body_dict.get('isLimited')
        supports_limited_ = body_dict.get('supportsLimited')
        supports_write_ = body_dict.get('supportsWrite')
        temperature_info_ = body_dict.get('temperatureInfo')
        if temperature_info_ is not None:
            new_list = []
            for item in temperature_info_:
                item = TemperatureData.from_dict(item)
                new_list.append(item)
            temperature_info_ = new_list
        checksum_ = body_dict.get('checksum')
        comments_ = body_dict.get('comments')
        return cls(
            date_=date_,
            next_recommended_date_=next_recommended_date_,
            recommended_interval_=recommended_interval_,
            is_limited_=is_limited_,
            supports_limited_=supports_limited_,
            supports_write_=supports_write_,
            temperature_info_=temperature_info_,
            checksum_=checksum_,
            comments_=comments_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`ExternalCalibrationData` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`ExternalCalibrationData`.
        :rtype: ExternalCalibrationData
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`ExternalCalibrationData` using a body
        of type :class:`bytes` or :class:`bytesarray`.

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`ExternalCalibrationData`.
        :rtype: ExternalCalibrationData
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        date_ = self.date
        next_recommended_date_ = self.next_recommended_date
        recommended_interval_ = self.recommended_interval
        is_limited_ = self.is_limited
        supports_limited_ = self.supports_limited
        supports_write_ = self.supports_write
        temperature_info_ = self.temperature_info
        if temperature_info_ is not None:
            new_list = []
            for item in temperature_info_:
                new_list.append(item.to_dict())
            temperature_info_ = new_list
        checksum_ = self.checksum
        comments_ = self.comments
        return {
            'date': date_,
            'nextRecommendedDate': next_recommended_date_,
            'recommendedInterval': recommended_interval_,
            'isLimited': is_limited_,
            'supportsLimited': supports_limited_,
            'supportsWrite': supports_write_,
            'temperatureInfo': temperature_info_,
            'checksum': checksum_,
            'comments': comments_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')


class SelfCalibrationData(object):
    """
    SelfCalibrationData custom data type.
    """
    def __init__(self,
                 date_,
                 is_limited_,
                 temperature_info_):
        """
        :param date_: date
        :type date_: str
        :param is_limited_: is_limited
        :type is_limited_: bool
        :param temperature_info_: temperature_info
        :type temperature_info_: list(TemperatureData)
        """
        self.date = date_
        self.is_limited = is_limited_
        self.temperature_info = temperature_info_

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`SelfCalibrationData` using a dictionary.

        :param body_dict: A dictionary representing the body.
        :type body_dict: dict
        :return: A new instance of :class:`SelfCalibrationData`.
        :rtype: SelfCalibrationData
        """
        date_ = body_dict.get('date')
        is_limited_ = body_dict.get('isLimited')
        temperature_info_ = body_dict.get('temperatureInfo')
        if temperature_info_ is not None:
            new_list = []
            for item in temperature_info_:
                item = TemperatureData.from_dict(item)
                new_list.append(item)
            temperature_info_ = new_list
        return cls(
            date_=date_,
            is_limited_=is_limited_,
            temperature_info_=temperature_info_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`SelfCalibrationData` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`SelfCalibrationData`.
        :rtype: SelfCalibrationData
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`SelfCalibrationData` using a body
        of type :class:`bytes` or :class:`bytesarray`.

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`SelfCalibrationData`.
        :rtype: SelfCalibrationData
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        date_ = self.date
        is_limited_ = self.is_limited
        temperature_info_ = self.temperature_info
        if temperature_info_ is not None:
            new_list = []
            for item in temperature_info_:
                new_list.append(item.to_dict())
            temperature_info_ = new_list
        return {
            'date': date_,
            'isLimited': is_limited_,
            'temperatureInfo': temperature_info_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')


class AssetData(object):
    """
    AssetData custom data type.
    """
    def __init__(self,
                 resource_uri_,
                 serial_number_,
                 vendor_number_,
                 model_number_,
                 supports_self_calibration_,
                 self_calibration_entry_,
                 supports_external_calibration_,
                 external_calibration_entry_,
                 temperature_info_):
        """
        :param resource_uri_: resource_uri
        :type resource_uri_: str
        :param serial_number_: serial_number
        :type serial_number_: str
        :param vendor_number_: vendor_number
        :type vendor_number_: long
        :param model_number_: model_number
        :type model_number_: long
        :param supports_self_calibration_: supports_self_calibration
        :type supports_self_calibration_: bool
        :param self_calibration_entry_: self_calibration_entry
        :type self_calibration_entry_: SelfCalibrationData
        :param supports_external_calibration_: supports_external_calibration
        :type supports_external_calibration_: bool
        :param external_calibration_entry_: external_calibration_entry
        :type external_calibration_entry_: ExternalCalibrationData
        :param temperature_info_: temperature_info
        :type temperature_info_: list(TemperatureData)
        """
        self.resource_uri = resource_uri_
        self.serial_number = serial_number_
        self.vendor_number = vendor_number_
        self.model_number = model_number_
        self.supports_self_calibration = supports_self_calibration_
        self.self_calibration_entry = self_calibration_entry_
        self.supports_external_calibration = supports_external_calibration_
        self.external_calibration_entry = external_calibration_entry_
        self.temperature_info = temperature_info_

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`AssetData` using a dictionary.

        :param body_dict: A dictionary representing the body.
        :type body_dict: dict
        :return: A new instance of :class:`AssetData`.
        :rtype: AssetData
        """
        resource_uri_ = body_dict.get('resourceUri')
        serial_number_ = body_dict.get('serialNumber')
        vendor_number_ = body_dict.get('vendorNumber')
        model_number_ = body_dict.get('modelNumber')
        supports_self_calibration_ = body_dict.get('supportsSelfCalibration')
        self_calibration_entry_ = body_dict.get('selfCalibrationEntry')
        if self_calibration_entry_ is not None:
            self_calibration_entry_ = SelfCalibrationData.from_dict(self_calibration_entry_)
        supports_external_calibration_ = body_dict.get('supportsExternalCalibration')
        external_calibration_entry_ = body_dict.get('externalCalibrationEntry')
        if external_calibration_entry_ is not None:
            external_calibration_entry_ = ExternalCalibrationData.from_dict(external_calibration_entry_)
        temperature_info_ = body_dict.get('temperatureInfo')
        if temperature_info_ is not None:
            new_list = []
            for item in temperature_info_:
                item = TemperatureData.from_dict(item)
                new_list.append(item)
            temperature_info_ = new_list
        return cls(
            resource_uri_=resource_uri_,
            serial_number_=serial_number_,
            vendor_number_=vendor_number_,
            model_number_=model_number_,
            supports_self_calibration_=supports_self_calibration_,
            self_calibration_entry_=self_calibration_entry_,
            supports_external_calibration_=supports_external_calibration_,
            external_calibration_entry_=external_calibration_entry_,
            temperature_info_=temperature_info_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`AssetData` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`AssetData`.
        :rtype: AssetData
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`AssetData` using a body
        of type :class:`bytes` or :class:`bytesarray`.

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`AssetData`.
        :rtype: AssetData
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        resource_uri_ = self.resource_uri
        serial_number_ = self.serial_number
        vendor_number_ = self.vendor_number
        model_number_ = self.model_number
        supports_self_calibration_ = self.supports_self_calibration
        self_calibration_entry_ = self.self_calibration_entry
        if self_calibration_entry_ is not None:
            self_calibration_entry_ = self_calibration_entry_.to_dict()
        supports_external_calibration_ = self.supports_external_calibration
        external_calibration_entry_ = self.external_calibration_entry
        if external_calibration_entry_ is not None:
            external_calibration_entry_ = external_calibration_entry_.to_dict()
        temperature_info_ = self.temperature_info
        if temperature_info_ is not None:
            new_list = []
            for item in temperature_info_:
                new_list.append(item.to_dict())
            temperature_info_ = new_list
        return {
            'resourceUri': resource_uri_,
            'serialNumber': serial_number_,
            'vendorNumber': vendor_number_,
            'modelNumber': model_number_,
            'supportsSelfCalibration': supports_self_calibration_,
            'selfCalibrationEntry': self_calibration_entry_,
            'supportsExternalCalibration': supports_external_calibration_,
            'externalCalibrationEntry': external_calibration_entry_,
            'temperatureInfo': temperature_info_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')


#
# AssetPerformanceManagement service
#


class AssetPerformanceManagementMinionCalibrationUpdatedBroadcast(BroadcastMessage):
    """
    AssetPerformanceManagementMinionCalibrationUpdatedBroadcast JSON broadcast message.
    """
    def __init__(self,
                 minion_id_,
                 assets_):
        """
        :param minion_id_: minion_id
        :type minion_id_: str
        :param assets_: assets
        :type assets_: list(AssetData)
        """
        self.minion_id = minion_id_
        self.assets = assets_
        header = MessageHeader()
        header.set_message_name('AssetPerformanceManagementMinionCalibrationUpdatedBroadcast')
        header.set_content_type(JSON_MESSAGE_CONTENT_TYPE)
        routing_key = MessageHeader.generate_routing_key(None, 'AssetPerformanceManagementMinionCalibrationUpdatedBroadcast')
        header.set_routing_key(routing_key)
        super(AssetPerformanceManagementMinionCalibrationUpdatedBroadcast, self).__init__(header, None)

    @classmethod
    def from_dict(cls, body_dict):
        """
        Create a new instance of :class:`AssetPerformanceManagementMinionCalibrationUpdatedBroadcast` using a dictionary.

        :param body_dict: The body as a dictionary.
        :type body_dict: dict
        :return: A new instance of :class:`AssetPerformanceManagementMinionCalibrationUpdatedBroadcast`.
        :rtype: AssetPerformanceManagementMinionCalibrationUpdatedBroadcast
        """
        minion_id_ = body_dict.get('minionId')
        assets_ = body_dict.get('assets')
        if assets_ is not None:
            new_list = []
            for item in assets_:
                item = AssetData.from_dict(item)
                new_list.append(item)
            assets_ = new_list
        return cls(
            minion_id_=minion_id_,
            assets_=assets_
        )

    @classmethod
    def from_json(cls, body_json):
        """
        Create a new instance of :class:`AssetPerformanceManagementMinionCalibrationUpdatedBroadcast` using a JSON string.

        :param body_json: A string in JSON format representing the body.
        :type body_json: str
        :return: A new instance of :class:`AssetPerformanceManagementMinionCalibrationUpdatedBroadcast`.
        :rtype: AssetPerformanceManagementMinionCalibrationUpdatedBroadcast
        """
        body_dict = json.loads(body_json)
        return cls.from_dict(body_dict)

    @classmethod
    def from_body_bytes(cls, body_bytes):
        """
        Create a new instance of :class:`AssetPerformanceManagementMinionCalibrationUpdatedBroadcast` using a body
        of type :class:`bytes` or :class:`bytesarray`,

        :param body_bytes: The body to use.
        :type body_bytes: bytes or bytesarray
        :return: A new instance of :class:`AssetPerformanceManagementMinionCalibrationUpdatedBroadcast`.
        :rtype: AssetPerformanceManagementMinionCalibrationUpdatedBroadcast
        """
        body_json = str(body_bytes, 'utf-8')
        return cls.from_json(body_json)

    @classmethod
    def from_message(cls, message):
        """
        Create a new instance of :class`AssetPerformanceManagementMinionCalibrationUpdatedBroadcast` using a
        :class:`niskyline.messagebus.message_base.MessageBase` derived message.

        :param message: The message to use as the basis for this class instance.
        :type message: niskyline.messagebus.message_base.MessageBase
        :return: A new instance of :class`AssetPerformanceManagementMinionCalibrationUpdatedBroadcast`.
        :rtype: AssetPerformanceManagementMinionCalibrationUpdatedBroadcast
        """
        instance = cls.from_body_bytes(message.get_body_bytes())
        instance.set_correlation_id(message.get_correlation_id())
        instance.set_reply_to(message.get_reply_to())
        return instance

    def to_dict(self):
        """
        Returns a dictionary representing the data in this object.

        :return: A dictionary representing the data in this object.
        :rtype: dict
        """
        minion_id_ = self.minion_id
        assets_ = self.assets
        if assets_ is not None:
            new_list = []
            for item in assets_:
                new_list.append(item.to_dict())
            assets_ = new_list
        return {
            'minionId': minion_id_,
            'assets': assets_
        }

    def to_json(self):
        """
        Returns a JSON string representing the data in this object.

        :return: A JSON string representing the data in this object.
        :rtype: str
        """
        body_dict = self.to_dict()
        return json.dumps(body_dict, separators=(',', ':'))

    def to_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        body_json = self.to_json()
        return bytearray(body_json, 'utf-8')

    def to_message(self, request_message=None):
        """
        Returns a :class:`niskyline.messagebus.message_base.MessageBase`
        object representing the data in this object.

        :param request_message: Request message if this is a response.
        :type request_message: niskyline.messagebus.message_base.MessageBase or None
        :return: A :class:`niskyline.messagebus.message_base.MessageBase`
            object representing the data in this object.
        :rtype: niskyline.messagebus.message_base.MessageBase
        """
        header = self.get_header()
        if request_message:
            request_header = request_message.get_header()
            header.set_correlation_id(request_header.get_correlation_id())
        body_bytes = self.to_body_bytes()
        return MessageBase(header, body_bytes)

    def get_body_bytes(self):
        """
        Returns a :class:`bytesarray` body representing the data in this object.

        :return: A :class:`bytesarray` body representing the data in this object.
        :rtype: bytesarray
        """
        self._body = self.to_body_bytes()  # pylint: disable=attribute-defined-outside-init
        return self._body
